<?php
/**
 * Courses Section options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

$wp_customize->add_section( 'corporate_education_pro_courses', array(
	'title'             => esc_html__( 'Courses','corporate-education-pro' ),
	'description'       => esc_html__( 'Courses Section Options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_sections_panel',
) );

// courses Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[courses_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['courses_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[courses_enable]', array(
	'label'            	=> esc_html__( 'Enable Courses Section', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_courses',
	'type'             	=> 'checkbox',
) );

// courses Section title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[courses_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['courses_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[courses_title]', array(
	'label'            	=> esc_html__( 'Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_courses',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_courses_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[courses_title]', array(
		'selector'            => '#featured-courses .wrapper .entry-header h2.entry-title',
		'settings'            => 'corporate_education_pro_theme_options[courses_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_courses_title',
    ) );
}


// courses Section subtitle setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[courses_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['courses_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[courses_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_courses',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_courses_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[courses_sub_title]', array(
		'selector'            => '#featured-courses .wrapper .entry-header p.entry-title-desc',
		'settings'            => 'corporate_education_pro_theme_options[courses_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_courses_sub_title',
    ) );
}

// courses Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[courses_content_type]', array(
	'default'          	=> $options['courses_content_type'],
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[courses_content_type]', array(
	'label'            	=> esc_html__( 'Courses Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_courses',
	'type'             	=> 'select',
	'active_callback'	=> 'corporate_education_pro_is_courses_enable',
	'choices'			=> corporate_education_pro_courses_content_type(),
) );

// Add slider number setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[no_of_courses]', array(
	'default'           => $options['no_of_courses'],
	'sanitize_callback' => 'corporate_education_pro_sanitize_number_range',
	'validate_callback' => 'corporate_education_pro_validate_course_count',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[no_of_courses]', array(
	'label'           	=> esc_html__( 'Number of Courses', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then referesh the page to see the change.', 'corporate-education-pro' ),
	'section'         	=> 'corporate_education_pro_courses',
	'type'            	=> 'number',
	'active_callback' 	=> 'corporate_education_pro_courses_content_count',
	'input_attrs'     	=> array(
		'max' 	=> 6,
		'min' 	=> 3,
		'style' => 'width:100px'
	)
) );

// courses Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[courses_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[courses_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_courses_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 6. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_courses',
	'type'				=> 'text',
) );

// courses Section category setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[courses_content_category]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Dropdown_Single_Category_Control( $wp_customize, 'corporate_education_pro_theme_options[courses_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'corporate-education-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'corporate-education-pro' ),
	'section'         => 'corporate_education_pro_courses',
	'type'			  => 'dropdown-category',
	'active_callback' => 'corporate_education_pro_courses_content_category',
) ) );

// courses Section content type course setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[courses_content_course]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[courses_content_course]', array(
	'active_callback'	=> 'corporate_education_pro_courses_content_course',
	'label'             => esc_html__( 'Input Courses Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 6. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_courses',
	'type'				=> 'text',
) );

// courses Section category setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[courses_content_course_category]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Dropdown_Single_Category_Control( $wp_customize, 'corporate_education_pro_theme_options[courses_content_course_category]', array(
	'label'           => esc_html__( 'Select Course Category', 'corporate-education-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'corporate-education-pro' ),
	'section'         => 'corporate_education_pro_courses',
	'taxonomy'		  => 'tp-course-category',
	'type'			  => 'dropdown-category',
	'active_callback' => 'corporate_education_pro_courses_content_couse_category',
) ) );
