<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

$wp_customize->add_section( 'corporate_education_pro_service', array(
	'title'             => esc_html__( 'Services','corporate-education-pro' ),
	'description'       => esc_html__( 'Services Section Options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_sections_panel',
) );

// service Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['service_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[service_enable]', array(
	'label'            	=> esc_html__( 'Enable Service Section', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_service',
	'type'             	=> 'checkbox',
) );

// service Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_intro_content_type]', array(
	'default'          	=> $options['service_intro_content_type'],
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[service_intro_content_type]', array(
	'label'            	=> esc_html__( 'Service Intro Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_service',
	'type'             	=> 'select',
	'active_callback'	=> 'corporate_education_pro_is_service_enable',
	'choices'			=> corporate_education_pro_intro_content_type(),
) );

// // service Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_intro_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[service_intro_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_service_intro_content_post',
	'label'             => esc_html__( 'Input Post Id', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_service',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_intro_content_page]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_page'
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[service_intro_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'corporate-education-pro' ),
	'section'        	=> 'corporate_education_pro_service',
	'active_callback' 	=> 'corporate_education_pro_service_intro_content_page',
	'type'				=> 'dropdown-pages'
) );

// call_to_action Section background setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_intro_image]', array(
	'default'           => $options['service_intro_image'],
	'sanitize_callback' => 'corporate_education_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'corporate_education_pro_theme_options[service_intro_image]',
		array(
		'label'       		=> esc_html__( 'Select Image', 'corporate-education-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'corporate-education-pro' ), 400, 270 ),
		'section'     		=> 'corporate_education_pro_service',
		'active_callback'	=> 'corporate_education_pro_service_intro_content_custom',
) ) );

// service Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_intro_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['service_intro_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[service_intro_title]', array(
	'label'            	=> esc_html__( 'Intro Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_service',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_service_intro_content_custom',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[service_intro_title]', array(
		'selector'            => '#featured-services .featured-services-wrapper .entry-header h2.entry-title',
		'settings'            => 'corporate_education_pro_theme_options[service_intro_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_service_intro_title',
    ) );
}

// service Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_intro_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['service_intro_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[service_intro_sub_title]', array(
	'label'            	=> esc_html__( 'Intro Sub Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_service',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_service_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[service_intro_sub_title]', array(
		'selector'            => '#featured-services .featured-services-wrapper .entry-header p.entry-title-desc',
		'settings'            => 'corporate_education_pro_theme_options[service_intro_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_service_intro_sub_title',
    ) );
}

// service Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_intro_description]', array(
	'sanitize_callback'	=> 'wp_kses_post',
	'default'          	=> $options['service_intro_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[service_intro_description]', array(
	'label'            	=> esc_html__( 'Intro Descrition', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_service',
	'type'             	=> 'textarea',
	'active_callback'	=> 'corporate_education_pro_service_intro_content_custom',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[service_intro_description]', array(
		'selector'            => '#featured-services .featured-services-wrapper .entry-content p',
		'settings'            => 'corporate_education_pro_theme_options[service_intro_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_service_intro_description',
    ) );
}

// service Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_intro_btn_label]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['service_intro_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[service_intro_btn_label]', array(
	'label'            	=> esc_html__( 'Intro Button Label', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_service',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_service_intro_content_custom',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[service_intro_btn_label]', array(
		'selector'            => '#featured-services .featured-services-wrapper .entry-content .view-more a',
		'settings'            => 'corporate_education_pro_theme_options[service_intro_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_service_intro_btn_label',
    ) );
}

// service Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_intro_btn_url]', array(
	'sanitize_callback'	=> 'esc_url_raw',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[service_intro_btn_url]', array(
	'label'            	=> esc_html__( 'Intro Button Link', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_service',
	'type'             	=> 'url',
	'active_callback'	=> 'corporate_education_pro_service_intro_content_custom',
) );

// service post hr setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Customize_Horizontal_Line( $wp_customize, 'corporate_education_pro_theme_options[service_hr]',
	array(
		'section'         => 'corporate_education_pro_service',
		'active_callback' => 'corporate_education_pro_is_service_enable',
		'type'			  => 'hr'
) ) );

// service Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[service_content_type]', array(
	'label'            	=> esc_html__( 'Services Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_service',
	'type'             	=> 'select',
	'active_callback'	=> 'corporate_education_pro_is_service_enable',
	'choices'			=> corporate_education_pro_common_content_type(),
) );

// service Section category setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Dropdown_Single_Category_Control( $wp_customize, 'corporate_education_pro_theme_options[service_content_category]', array(
	'label'           => esc_html__( 'Select Services Category', 'corporate-education-pro' ),
	'description'     => esc_html__( 'Four latest posts from selected category will be shown.', 'corporate-education-pro' ),
	'section'         => 'corporate_education_pro_service',
	'type'			  => 'dropdown-category',
	'active_callback' => 'corporate_education_pro_services_content_category',
) ) );

// service Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_content_post]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[service_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_services_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 4. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_service',
	'type'				=> 'text'
) );

for ( $i = 1; $i <= 4; $i++ ) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'corporate_education_pro_theme_options[service_content_page_'.$i.']', array(
		'sanitize_callback' => 'corporate_education_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'corporate_education_pro_theme_options[service_content_page_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'corporate-education-pro' ), $i ),
		'section'        	=> 'corporate_education_pro_service',
		'active_callback' 	=> 'corporate_education_pro_services_content_page',
		'type'				=> 'dropdown-pages'
	) );
}