<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */

$wp_customize->add_section( 'corporate_education_pro_testimonial', array(
	'title'             => esc_html__( 'Testimonial','corporate-education-pro' ),
	'description'       => esc_html__( 'Testimonial Section Options.', 'corporate-education-pro' ),
	'panel'             => 'corporate_education_pro_sections_panel',
) );

// testimonial Section enable setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[testimonial_enable]', array(
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_checkbox',
	'default'          	=> $options['testimonial_enable'],
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[testimonial_enable]', array(
	'label'            	=> esc_html__( 'Enable Testimonial Section', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_testimonial',
	'type'             	=> 'checkbox',
) );

// testimonial Section title setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[testimonial_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['testimonial_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[testimonial_title]', array(
	'label'            	=> esc_html__( 'Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_testimonial',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_testimonial_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[testimonial_title]', array(
		'selector'            => '#client-testimonial .wrapper .entry-header h2.entry-title',
		'settings'            => 'corporate_education_pro_theme_options[testimonial_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_testimonial_title',
    ) );
}

// testimonial Section subtitle setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[testimonial_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['testimonial_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[testimonial_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_testimonial',
	'type'             	=> 'text',
	'active_callback'	=> 'corporate_education_pro_is_testimonial_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corporate_education_pro_theme_options[testimonial_sub_title]', array(
		'selector'            => '#client-testimonial .wrapper .entry-header p.entry-title-desc',
		'settings'            => 'corporate_education_pro_theme_options[testimonial_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corporate_education_pro_testimonial_sub_title',
    ) );
}

// testimonial Section content type setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback'	=> 'corporate_education_pro_sanitize_select',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[testimonial_content_type]', array(
	'label'            	=> esc_html__( 'Testimonial Content Type', 'corporate-education-pro' ),
	'section'          	=> 'corporate_education_pro_testimonial',
	'type'             	=> 'select',
	'active_callback'	=> 'corporate_education_pro_is_testimonial_enable',
	'choices'			=> corporate_education_pro_testimonial_content_type(),
) );

// Add slider number setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[no_of_testimonial]', array(
	'default'           => $options['no_of_testimonial'],
	'sanitize_callback' => 'corporate_education_pro_sanitize_number_range',
	'validate_callback' => 'corporate_education_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[no_of_testimonial]', array(
	'label'           	=> esc_html__( 'Number of testimonial', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 9. Please input the valid number and save. Then referesh the page to see the change.', 'corporate-education-pro' ),
	'section'         	=> 'corporate_education_pro_testimonial',
	'type'            	=> 'number',
	'active_callback' 	=> 'corporate_education_pro_testimonial_content_count',
	'input_attrs'     	=> array(
		'max' 	=> 9,
		'min' 	=> 3,
		'style' => 'width:100px'
	)
) );

// testimonial Section content type post setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[testimonial_content_post]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[testimonial_content_post]', array(
	'active_callback'	=> 'corporate_education_pro_testimonial_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 9. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_testimonial',
	'type'				=> 'text',
) );

// testimonial Section category setting and control
$wp_customize->add_setting( 'corporate_education_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'corporate_education_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Corporate_Education_Pro_Dropdown_Single_Category_Control( $wp_customize, 'corporate_education_pro_theme_options[testimonial_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'corporate-education-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'corporate-education-pro' ),
	'section'         => 'corporate_education_pro_testimonial',
	'type'			  => 'dropdown-category',
	'active_callback' => 'corporate_education_pro_testimonial_content_category',
) ) );

// testimonial Section content type testimonial setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[testimonial_content_testimonial]', array(
	'validate_callback' => 'corporate_education_pro_validate_post_id',
	'sanitize_callback' => 'corporate_education_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'corporate_education_pro_theme_options[testimonial_content_testimonial]', array(
	'active_callback'	=> 'corporate_education_pro_testimonial_content_testimonial',
	'label'             => esc_html__( 'Input Testimonial Post Ids', 'corporate-education-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 9. ie: 11, 24, 34', 'corporate-education-pro' ),
	'section'           => 'corporate_education_pro_testimonial',
	'type'				=> 'text',
) );

// testimonial section content type recent testimonial setting and control.
$wp_customize->add_setting( 'corporate_education_pro_theme_options[testimonial_content_recent_testimonial]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Corporate_Education_Pro_Note_Control( $wp_customize, 'corporate_education_pro_theme_options[testimonial_content_recent_testimonial]', array(
	'label'       => esc_html__( 'Latest Testimonial will be shown.', 'corporate-education-pro' ),
	'section'         	=> 'corporate_education_pro_testimonial',
	'type'            	=> 'description',
	'active_callback' 	=> 'corporate_education_pro_testimonial_content_recent',
) ) );