<?php 
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_about_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if about is enabled
        $enable_about = apply_filters( 'corporate_education_pro_section_status', true, 'about_enable' );

        if ( true !== $enable_about ) {
            return false;
        }

        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_about_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render about section now.
        corporate_education_pro_render_about_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_primary_content_action', 'corporate_education_pro_add_about_section', 20 );


if ( ! function_exists( 'corporate_education_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input about section details.
    */
    function corporate_education_pro_get_about_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // about type
        $about_content_type  = $options['about_content_type'];

        $content = array();
        switch ( $about_content_type ) {
          	case 'demo':
                $content[0]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/letter-backgound.jpg';
                $content[0]['title']    = esc_html__( 'About Us', 'corporate-education-pro' );
                $content[0]['excerpt']  = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam eget augue quis elit tempor laoreet. Vestibulum purus quam, vestibulum sed malesuada id, hendrerit nec dolor. Nulla risus erat, rutrum id felis non, efficitur varius mi. Interdum et malesuada fames ac ante ipsum primis in faucibus. Pellentesque sagittis gravida dolor, sed auctor risus faucibus eu.Integer finibus purus eu velit vestibulum, at scelerisque arcu tempor. Nam at justo sed tortor condimentum mollis. Donec nec urna dui. Sed ut iaculis lacus. Morbi vulputate sapien risus, non finibus diam suscipit porttitor. Nunc eu rhoncus mi, quis aliquam nisi.', 'corporate-education-pro' );
            break;        

            case 'custom':
                $content[0]['img_array'][0] = ! empty( $options['about_image'] ) ? $options['about_image'] : get_template_directory_uri() . '/assets/uploads/letter-backgound.jpg';
                $content[0]['title']    = ! empty( $options['about_title'] ) ? $options['about_title'] : esc_html__( 'About Us', 'corporate-education-pro' );
                $content[0]['excerpt']  = ! empty( $options['about_excerpt'] ) ? $options['about_excerpt'] : '';
                                            
            break;

            case 'post':
                $post_id = '';
                
                if ( ! empty( $options['about_content_post'] ) )
                    $post_id = absint( $options['about_content_post'] );

                // Bail if no valid pages are selected.
                if ( empty( $post_id ) ) {
                    return $input;
                }

                $img_array = null;
                if ( has_post_thumbnail( $post_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'corporate-education-pro-medium' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg';
                }
                if ( isset( $img_array ) ) {
                    $content[0]['img_array'] = $img_array;
                }
                $content[0]['title']    = get_the_title( $post_id );
                $content[0]['excerpt']  = get_post_field( 'post_content', $post_id );
                                            
          	break;

            case 'page':
                $page_id = '';
                
                if ( ! empty( $options['about_content_page'] ) )
                    $page_id = absint( $options['about_content_page'] );

                // Bail if no valid pages are selected.
                if ( empty( $page_id ) ) {
                    return $input;
                }

                $img_array = null;
                if ( has_post_thumbnail( $page_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'corporate-education-pro-medium' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg';
                }
                if ( isset( $img_array ) ) {
                    $content[0]['img_array'] = $img_array;
                }
                $content[0]['title']    = get_the_title( $page_id );
                $content[0]['excerpt']  = get_post_field( 'post_content', $page_id );
                                            
            break;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'corporate_education_pro_filter_about_section_details', 'corporate_education_pro_get_about_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_about_section' ) ) :
    /**
    * Start about section
    *
    * @return string about content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_about_section( $content_details ) {
        $options = corporate_education_pro_get_theme_options();
        $sub_title = ! empty( $options['about_sub_title'] ) ? $options['about_sub_title'] : '';
        $alphabet = ! empty( $options['about_alphabet'] ) ? $options['about_alphabet'] : '';

        if ( empty( $content_details ) ) {
            return;
        }

        foreach ( $content_details as $content_detail ) :
        ?>
            <section id="hero-section" class="page-section col-2">
                <div class="white-shape top"></div>
                <div class="white-shape top left"></div>
                <div class="white-shape bottom move-down right"></div>

                <div class="wrapper">
                    <div class="row">
                        <?php if ( ! empty( $alphabet ) ) : ?>
                            <div class="hentry">
                                <h2><span style="background-image: url('<?php echo esc_url( $content_detail['img_array'][0] ); ?>');"><?php echo esc_html( $alphabet ); ?></span></h2>
                            </div><!-- .hentry -->
                        <?php endif; ?>
                        <div class="hentry">
                            <header class="entry-header">
                                <h2 class="entry-title"><?php echo esc_html( $content_detail['title'] ); ?></h2>
                                <?php if ( ! empty( $sub_title ) ) : ?>
                                    <p class="entry-title-desc"><?php echo esc_html( $sub_title ); ?></p>
                                <?php endif; ?>
                            </header>

                            <div class="entry-content">
                                <?php echo wp_kses_post( $content_detail['excerpt'] ); ?>
                            </div><!-- .entry-content -->
                        </div><!-- .hentry -->
                    </div><!-- .row -->
                </div><!-- .wrapper -->
            </section><!-- #hero-section -->
        <?php endforeach;
    }
endif;